==> eea.testcase-0.1.zip: eea.testcase-0.1/eea/testcase/layer.py <==
from Testing import ZopeTestCase
from Products.Five import zcml
from Products.Five import fiveconfigure
from Products.CMFCore.utils import getToolByName
from Products.PloneTestCase.layer import PloneSite
from transaction import commit
from Products.PloneTestCase.setup import portal_owner
from AccessControl.SecurityManagement import newSecurityManager

class EEAMegaLayer(PloneSite):
    """Layer that includes all EEA products

    This is close to what's on the live site.
    """

    PRODUCTS = ['PlonePAS', 'FiveSite', 'ATVocabularyManager', 'EEAContentTypes', 'EEADesign2006', 'PloneRSSPortlet', 'valentine.linguaflow', 'valentine.imagescales', 'LinguaPlone', 'RichTopic', 'ThemeCentre', 'kupu', 'PloneLanguageTool', 'EEAPloneAdmin', 'CMFSquidTool', 'CacheSetup']

    @classmethod
    def setUp(cls):
        import Products.Five
        import Products.CMFSquidTool
        fiveconfigure.debug_mode = True
        zcml.load_config('configure.zcml', Products.Five)
        zcml.load_config('configure.zcml', Products.CMFSquidTool)    
        fiveconfigure.debug_mode = False

        for i in EEAMegaLayer.PRODUCTS:
            ZopeTestCase.installProduct(i)

        root = ZopeTestCase.app()
        portal = root.plone
        uf = portal.acl_users
        uf.userFolderAddUser('layer_manager', 'user_password', ['Member', 'Manager'], [])
        user = uf.getUserById('layer_manager')
        if not hasattr(user, 'aq_base'):
            user = user.__of__(uf)
        newSecurityManager(None, user)

        qi = getToolByName(portal, 'portal_quickinstaller')

        setup = getToolByName(portal, 'portal_setup')
        profile = 'profile-EEAContentTypes:eeacontenttypes'
        setup.setImportContext(profile)
        setup.runAllImportSteps()

        profile = 'profile-EEAContentTypes:testfixture'
        setup.setImportContext(profile)
        setup.runAllImportSteps()

        for i in EEAMegaLayer.PRODUCTS:
            qi.installProduct(i)

        commit()
        ZopeTestCase.close(root)
        
    @classmethod
    def tearDown(cls):
        pass

==> eea.testcase-0.2.zip: eea.testcase-0.2/eea/testcase/layer.py <==
from Testing import ZopeTestCase
from Products.Five import zcml
from Products.Five import fiveconfigure
from Products.CMFCore.utils import getToolByName
from Products.PloneTestCase.layer import PloneSite
from transaction import commit
#from Products.PloneTestCase.setup import portal_owner
from AccessControl.SecurityManagement import newSecurityManager

class EEAMegaLayer(PloneSite):
    """Layer that includes all EEA products

    This is close to what's on the live site.
    """

    PRODUCTS = ['PlonePAS', 'FiveSite', 'ATVocabularyManager', 'EEAContentTypes', 'EEADesign2006', 'valentine.linguaflow', 'valentine.imagescales', 'LinguaPlone', 'RichTopic', 'ThemeCentre', 'kupu', 'PloneLanguageTool', 'EEAPloneAdmin', 'CMFSquidTool', 'CacheSetup']

    @classmethod
    def setUp(cls):
        import Products.Five
        import Products.CMFSquidTool
        import valentine.imagescales
        fiveconfigure.debug_mode = True
        zcml.load_config('configure.zcml', Products.Five)
        zcml.load_config('configure.zcml', Products.CMFSquidTool)
        zcml.load_config('configure.zcml', valentine.imagescales)
        fiveconfigure.debug_mode = False

        for i in EEAMegaLayer.PRODUCTS:
            ZopeTestCase.installProduct(i)

        root = ZopeTestCase.app()
        portal = root.plone
        uf = portal.acl_users
        uf.userFolderAddUser('layer_manager', 'user_password', ['Member', 'Manager'], [])
        user = uf.getUserById('layer_manager')
        if not hasattr(user, 'aq_base'):
            user = user.__of__(uf)
        newSecurityManager(None, user)

        qi = getToolByName(portal, 'portal_quickinstaller')

        setup = getToolByName(portal, 'portal_setup')
        profile = 'profile-EEAContentTypes:eeacontenttypes'
        setup.setImportContext(profile)
        setup.runAllImportSteps()

        profile = 'profile-EEAContentTypes:testfixture'
        setup.setImportContext(profile)
        setup.runAllImportSteps()

        for i in EEAMegaLayer.PRODUCTS:
            qi.installProduct(i)

        commit()
        ZopeTestCase.close(root)

    @classmethod
    def tearDown(cls):
        pass
